==> socialfeed-8.x-1.0-rc1.tar.gz: socialfeed/README.md <==
# Social Feeds

## Introduction

- Social Feed module provides the user to fetch the data from their respective
Facebook, Twitter, and Instagram profiles and then display them accordingly as
per their requirement using the Drupal block system.

- Facebook APIs will allow you to display particular post types,
pictures, videos of your posts also the date of your post with
provision to provide number of count.

- Instagram APIs will allow you to display pictures from your
instagram profile with provision to provide number of count to be displayed
also provision to select the resolution of the image with options and you can
also provide the post link.

- Twitter APIs will allow you get the latest tweets with date
of your format and provision to provide number of count. Twitter APIs will
not work locally but only on live sites.

- This module is easy and simple to install and use if the project page
description or the README.txt file is followed correctly.

- This module is highly recommended for the both developers & non-developers
since the default layout of the blocks are plain and in simple text hence if
you're aware of working with CSS then this module will work for you like a
charm.

## Requirements

- PHP 5.4 and above.

## Installation

- Install as usual, see https://www.drupal.org/node/1897420 for further
information.

- Now, in your modules/ directory download the Social Feed module

- Enable the Social Feed module.

- Ensure composer dependencies for the module are installed

## Configuration

There are configuration forms for each social media platform, which you
can access at admin/config/services/socialfeed.

When enabled and configured properly, this module will display the Social Feed
form at admin/config/services/socialfeed, after this step you can use the
blocks from Drupal system to show the feeds from their respective services.

==> socialfeed-8.x-1.1.tar.gz: socialfeed/README.md <==
# Socialfeed

## Introduction

- Socialfeed module provides the user to fetch the data from their respective
Facebook, Twitter, and Instagram profiles and then display them accordingly as
per their requirement using the Drupal block system.

- Facebook APIs will allow you to display particular post types,
pictures, videos of your posts also the date of your post with
provision to provide number of count.

- Instagram APIs will allow you to display pictures from your
instagram profile with provision to provide number of count to be displayed, and
you can also provide the post link.

- Twitter APIs will allow you get the latest tweets with date
of your format and provision to provide number of count. Twitter APIs will
not work locally but only on live sites.

- This module is easy and simple to install and use if the project page
description or the README.txt file is followed correctly.

- This module is highly recommended for the both developers & non-developers
since the default layout of the blocks are plain and in simple text hence if
you're aware of working with CSS then this module will work for you like a
charm.

## Requirements

- PHP 5.4 and above.

## Installation

- Install as usual, see https://www.drupal.org/node/1897420 for further
information.

- Now, in your modules/ directory download the Socialfeed module

- Enable the Socialfeed module.

- Ensure composer dependencies for the module are installed

## Configuration

There are configuration forms for each social media platform, which you
can access at admin/config/services/socialfeed.

When enabled and configured properly, this module will display the Socialfeed
form at admin/config/services/socialfeed, after this step you can use the
blocks from Drupal system to show the feeds from their respective services.
